Доступ к количеству слушателей
Пред. | Глава 3. Настройка | След.

## Доступ к количеству слушателей

Количество активных слушателей знает сервер icecast2. Чтобы получить эту информацию, нужно запросить административную страницу по протоколу HTTP, затем распарсить её (к счастью, это XML-документ). Чтобы ardj мог делать это автоматически, в конфигурационном файле нужно указать параметры подключения к серверу:

    icecast_stats_url: "http://alice:secret@localhost:8180/admin/stats.xml"

Пред. | Наверх | След.
Взаимодействие с Libre.fm | Начало | Настройка сторонних программ